debuginfo

package
v0.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DebugInfo

type DebugInfo interface {
	// GetTarget returns the Target struct of the debugger instance
	GetTarget() Target

	// PCToLine returns the filename, line number and function from the stack memory address
	PCToLine(pc uint64) (file string, line int, fn *gosym.Func)

	// LineToPC returns the memory address, function or an error from the filename and line number
	LineToPC(file string, line int) (pc uint64, fn *gosym.Func, err error)

	// LookupFunc returns the Func struct whose name corresponds to the value of fn
	LookupFunc(fn string) *gosym.Func
}

func NewDebugInfo

func NewDebugInfo(path string, pid int) (DebugInfo, error)

type Target

type Target struct {
	Path string
	PID  int
	PGID int
}

Target represents information about the debugging target process

Jump to