Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DebugInfo ¶
type DebugInfo interface {
// GetTarget returns the Target struct of the debugger instance
GetTarget() Target
// PCToLine returns the filename, line number and function from the stack memory address
PCToLine(pc uint64) (file string, line int, fn *gosym.Func)
// LineToPC returns the memory address, function or an error from the filename and line number
LineToPC(file string, line int) (pc uint64, fn *gosym.Func, err error)
// LookupFunc returns the Func struct whose name corresponds to the value of fn
LookupFunc(fn string) *gosym.Func
}
Click to show internal directories.
Click to hide internal directories.